@@ -1,8 +1,8 @@
 from .array_helper import ArrayHelper
 from .datetime_helper import DateTimeConstants, DateTimeEncoder, get_current_time_in_seconds, get_day_of_month, \
 	get_day_of_week, get_half_year, get_month, get_quarter, get_week_of_month, get_week_of_year, get_year, is_date, \
-	is_date_or_time_instance, is_date_plus_format, is_datetime, is_time, month_diff, translate_date_format_to_memory, \
-	truncate_time, try_to_date, try_to_time, year_diff
+	is_date_or_time_instance, is_date_plus_format, is_datetime, is_time, month_diff, to_previous_month, \
+	to_previous_week, to_yesterday, translate_date_format_to_memory, truncate_time, try_to_date, try_to_time, year_diff
 from .json_helper import serialize_to_json
 from .logger import init_log
 from .numeric_helper import is_decimal, is_numeric_instance, try_to_decimal
